# == Class: postfix
#
# This class sets up a Postfix mail server.
#
# === Parameters
#
# [*daemon_directory*], [*sendmail_path*] et al.
#   These parameters are actual Postfix main.cf settings. You can pass them
#   either as arrays or as strings.
#
# === Variables
#
# === Examples
#
#  class { 'postfix':
#    transport_maps => 'regexp:/etc/postfix/transport.regex',
#    mydomain       => [$fqdn, $domain, 'example.net', '$myorigin'],
#  }
#
#
# Using an LDAP map:
#
#  class { 'postfix':
#    virtual_maps => 'ldap:virtual',
#  }
#
#  postfix::ldap_map { 'virtual':
#    server_host      => 'ldap.example.com',
#    search_base      => 'dc=example,dc=com',
#    query_filter     => '(|(mailLocalAddress=%s)(mailAcceptingAddress=%s))',
#    result_attribute => 'mailRoutingAddress',
#  }
#
# === Authors
#
# Arnaud Gomes-do-Vale <Arnaud.Gomes@ircam.fr>
#
# === Copyright
#
# Copyright 2013 Arnaud Gomes-do-Vale
#
class postfix (
  $daemon_directory                    = $postfix::params::daemon_directory,
  $sendmail_path                       = $postfix::params::sendmail_path,
  $newaliases_path                     = $postfix::params::newaliases_path,
  $mailq_path                          = $postfix::params::mailq_path,
  $transport_maps                      = $postfix::params::transport_maps,
  $relocated_maps                      = $postfix::params::relocated_maps,
  $alias_database                      = $postfix::params::alias_database,
  $alias_maps                          = $postfix::params::alias_maps,
  $inet_protocols                      = $postfix::params::inet_protocols,
  $mydomain                            = $postfix::params::mydomain,
  $mydestination                       = $postfix::params::mydestination,
  $mynetworks                          = $postfix::params::mynetworks,
  $mynetworks_style                    = $postfix::params::mynetworks_style,
  $inet_interfaces                     = $postfix::params::inet_interfaces,
  $message_size_limit                  = $postfix::params::message_size_limit,
  $unknown_local_recipient_reject_code = $postfix::params::unknown_local_recipient_reject_code,
  $relay_domains                       = $postfix::params::relay_domains,
  $content_filter                      = $postfix::params::content_filter,
  $header_checks                       = $postfix::params::header_checks,
  $smtpd_client_restrictions           = $postfix::params::smtpd_client_restrictions,
  $smtpd_recipient_restrictions        = $postfix::params::smtpd_recipient_restrictions,
  $smtp_bind_address6                  = $postfix::params::smtp_bind_address6,
  $myorigin                            = $postfix::params::myorigin,
  $relayhost                           = $postfix::params::relayhost,
  $virtual_maps                        = $postfix::params::virtual_maps,
  $local_header_rewrite_clients        = $postfix::params::local_header_rewrite_clients,
  $recipient_canonical_classes         = $postfix::params::recipient_canonical_classes,
  $recipient_canonical_maps            = $postfix::params::recipient_canonical_maps,
  $sender_canonical_classes            = $postfix::params::sender_canonical_classes,
  $sender_canonical_maps               = $postfix::params::sender_canonical_maps,
  $recipient_delimiter                 = $postfix::params::recipient_delimiter,
  $mailbox_transport                   = $postfix::params::mailbox_transport,
  $cyrus_destination_recipient_limit   = $postfix::params::cyrus_destination_recipient_limit,
  $notify_classes                      = $postfix::params::notify_classes,
  $maximal_queue_lifetime              = $postfix::params::maximal_queue_lifetime,
  $smtpd_sasl_auth_enable              = $postfix::params::smtpd_sasl_auth_enable,
  $smtpd_sasl_authenticated_header     = $postfix::params::smtpd_sasl_authenticated_header,
  $smtp_tls_CAfile                     = $postfix::params::smtp_tls_CAfile,
  $smtp_tls_security_level             = $postfix::params::smtp_tls_security_level,
  $smtpd_tls_CAfile                    = $postfix::params::smtpd_tls_CAfile,
  $smtpd_tls_cert_file                 = $postfix::params::smtpd_tls_cert_file,
  $smtpd_tls_key_file                  = $postfix::params::smtpd_tls_key_file,
  $smtpd_tls_received_header           = $postfix::params::smtpd_tls_received_header,
  $tls_random_source                   = $postfix::params::tls_random_source,
  $smtpd_tls_security_level            = $postfix::params::smtpd_tls_security_level,
  $smtpd_tls_loglevel                  = $postfix::params::smtpd_tls_loglevel,
  $master_services                     = $postfix::params::default_master_services,
) inherits postfix::params {

  class { 'postfix::install': } ~>
  class { 'postfix::config': } ~>
  class { 'postfix::service':
    before => Class['postfix'],
  }

}
