# == Define: postfix::ldap_map
#
# This definition manages a LDAP-stored Postfix map.
#
# === Parameters
#
# [*server_host*]
#   The LDAP server.
#
# [*search_base*]
#   The LDAP search base.
#
# [*query_filter*]
#   The LDAP filter.
#
# [*result_attribute*]
#   The LDAP attribute we use as a result.
#
# [*server_port*]
#   The LDAP TCP port. Defaults to 389.
#
# === Example
#
#   postfix::ldap_map { 'routing':
#     server_host      => 'ldap.example.com',
#     server_port      => '389',
#     search_base      => 'dc=example,dc=com',
#     query_filter     => '(|(mailLocalAddress=%s)(mailAcceptingAddress=%s))',
#     result_attribute => 'mailRoutingAddress',
#   }
#
define postfix::ldap_map (
  $server_host,
  $search_base,
  $query_filter,
  $result_attribute,
  $server_port = '389',
) {

  include postfix

  file { "${postfix::ldap_dir}/${title}.cf":
    ensure  => present,
    content => template('postfix/ldap.cf.erb'),
    owner   => 'root',
    group   => 'root',
    mode    => '0444',
  }

}
