# == Class: postfix::params
#
# This is a private class.
#
class postfix::params {

  case $osfamily {
    'Debian': {
      $daemon_directory = '/usr/lib/postfix'
      $mailq_path       = '/usr/bin/mailq'
      $newaliases_path  = '/usr/bin/newaliases'
      $sendmail_path    = '/usr/sbin/sendmail'
    }
    'RedHat': {
      $daemon_directory = '/usr/libexec/postfix'
      $mailq_path       = '/usr/bin/mailq.postfix'
      $newaliases_path  = '/usr/bin/newaliases.postfix'
      $sendmail_path    = '/usr/sbin/sendmail.postfix'
    }
    default: {
      fail("Module ${module_name} is unsupported on osfamily ${osfamily}.")
    }
  }

  $postfix_conf_dir = '/etc/postfix'
  $main_cf          = "${postfix_conf_dir}/main.cf"
  $master_cf        = "${postfix_conf_dir}/master.cf"
  $ldap_dir         = "${postfix_conf_dir}/ldap-maps.d"
  $postmap          = '/usr/sbin/postmap'

  $alias_database                      = 'hash:/etc/aliases'
  $alias_maps                          = 'hash:/etc/aliases'
  $content_filter                      = undef
  $cyrus_destination_recipient_limit   = undef
  $header_checks                       = undef
  $inet_interfaces                     = ['127.0.0.1', '::1']
  $inet_protocols                      = 'all'
  $local_header_rewrite_clients        = undef
  $mailbox_transport                   = undef
  $maximal_queue_lifetime              = undef
  $message_size_limit                  = '20000000'
  $mydestination                       = ['$myhostname', 'localhost.$mydomain', 'localhost']
  $mydomain                            = $domain
  $mynetworks                          = undef
  $mynetworks_style                    = undef
  $myorigin                            = undef
  $notify_classes                      = undef
  $recipient_canonical_classes         = undef
  $recipient_canonical_maps            = undef
  $recipient_delimiter                 = undef
  $relay_domains                       = ['$myhostname', 'localhost.$mydomain', '$mydomain']
  $relayhost                           = undef
  $relocated_maps                      = undef
  $sender_canonical_classes            = undef
  $sender_canonical_maps               = undef
  $smtp_bind_address6                  = undef
  $smtpd_client_restrictions           = undef
  $smtpd_recipient_restrictions        = undef
  $smtpd_sasl_auth_enable              = undef
  $smtpd_sasl_authenticated_header     = undef
  $smtpd_tls_CAfile                    = undef
  $smtpd_tls_cert_file                 = undef
  $smtpd_tls_key_file                  = undef
  $smtpd_tls_loglevel                  = undef
  $smtpd_tls_received_header           = undef
  $smtpd_tls_security_level            = undef
  $smtp_tls_CAfile                     = undef
  $smtp_tls_security_level             = undef
  $tls_random_source                   = undef
  $transport_maps                      = undef
  $unknown_local_recipient_reject_code = '450'
  $virtual_maps                        = undef

  $default_master_services = {
    'anvil'     => { type => 'unix', chroot => 'n', maxproc => '1', command => 'anvil', },
    'bounce'    => { type => 'unix', chroot => 'n', maxproc => '0', command => 'bounce', },
    'cleanup'   => { type => 'unix', private => 'n', chroot => 'n', maxproc => '0', command => 'cleanup', },
    'defer'     => { type => 'unix', chroot => 'n', maxproc => '0', command => 'bounce', },
    'discard'   => { type => 'unix', chroot => 'n', command => 'discard', },
    'error'     => { type => 'unix', chroot => 'n', command => 'error', },
    'flush'     => { type => 'unix', private => 'n', chroot => 'n', wakeup => '1000?', maxproc => '0', command => 'flush', },
    'lmtp'      => { type => 'unix', chroot => 'n', command => 'lmtp', },
    'local'     => { type => 'unix', unpriv => 'n', chroot => 'n', command => 'local', },
    'pickup'    => { type => 'fifo', private => 'n', chroot => 'n', wakeup => '60', maxproc => '1', command => 'pickup', },
    'proxymap'  => { type => 'unix', chroot => 'n', command => 'proxymap', },
    'qmgr'      => { type => 'fifo', private => 'n', chroot => 'n', wakeup => '300', maxproc => '1', command => 'qmgr', },
    'relay'     => { type => 'unix', chroot => 'n', command => 'smtp -o fallback_relay=', },
    'rewrite'   => { type => 'unix', chroot => 'n', command => 'trivial-rewrite', },
    'scache'    => { type => 'unix', chroot => 'n', maxproc => '1', command => 'scache', },
    'showq'     => { type => 'unix', private => 'n', chroot => 'n', command => 'showq', },
    'smtp_inet' => { service => 'smtp', type => 'inet', private => 'n', chroot => 'n', command => 'smtpd', },
    'smtp_unix' => { service => 'smtp', type => 'unix', chroot => 'n', command => 'smtp', },
    'tlsmgr'    => { type => 'unix', chroot => 'n', wakeup => '1000?', maxproc => '1', command => 'tlsmgr', },
    'trace'     => { type => 'unix', chroot => 'n', maxproc => '0', command => 'bounce', },
    'verify'    => { type => 'unix', chroot => 'n', command => 'verify', },
    'virtual'   => { type => 'unix', unpriv => 'n', chroot => 'n', command => 'virtual', },
  }
}
